@@ -4,10 +4,24 @@
 #' 
 #' @param out An object of class \code{\link{spwb}}, \code{\link{growth}} or \code{\link{pwb}}.
 #' @param measuredData A data frame with observed/measured values. Dates should be in row names, whereas columns should be named according to the type of output to be evaluated (see details).
-#' @param type A string with the kind of model output to be evaluated. Accepted values are \code{"SWC"} (soil moisture content), \code{"REW"} relative extractable water, \code{"ETR"} (total evapotranspiration), 
-#' \code{"SE+TR"} (modelled soil evaporation + transpiration against observed total evapotranspiration), \code{"E"} (transpiration per leaf area), \code{"LFMC"} (Live fuel moisture content), \code{"WP"} (plant water potentials), 
-#' \code{"BAI"} (basal area increment), \code{"DI"} (diameter increment), 
-#' \code{"DBH"} (diameter at breast height) or \code{"Height"} (plant height).
+#' @param type A string with the kind of model output to be evaluated. Accepted values are:
+#'     \itemize{
+#'       \item{\code{"SWC"}: Soil water content (percent volume). See details for specific soil layers.}
+#'       \item{\code{"RWC"}: Relative water content (relative to field capacity). See details for specific soil layers.}
+#'       \item{\code{"REW"}: Relative extractable water. See details for specific soil layers.}
+#'       \item{\code{"ETR"}: Total evapotranspiration.}
+#'       \item{\code{"SE+TR"}: Modelled soil evaporation + plant transpiration against observed total evapotranspiration}
+#'       \item{\code{"E"}: Transpiration per leaf area}
+#'       \item{\code{"LE"}: Latent heat (vaporisation) turbulent flux}
+#'       \item{\code{"H"}: Canopy sensible heat turbulent flux}
+#'       \item{\code{"GPP"}: Stand-level gross primary productivity}
+#'       \item{\code{"LFMC"}: Live fuel moisture content}
+#'       \item{\code{"WP"}: Plant water potentials}
+#'       \item{\code{"BAI"}: Basal area increment}
+#'       \item{\code{"DI"}: Diameter increment}
+#'       \item{\code{"DBH"}: Diameter at breast height}
+#'       \item{\code{"Height"}: Plant height}
+#'     }
 #' @param cohort A string of the cohort to be compared (e.g. "T1_68"). If \code{NULL} results for the first cohort will be evaluated.
 #' @param temporalResolution A string to indicate the temporal resolution of the model evaluation, which can be "day", "week", "month" or "year". Observed and modelled values are aggregated temporally (using either means or sums) before comparison.
 #' @param plotType Plot type to draw, either \code{"dynamics"} or \code{"scatter"}.
@@ -23,9 +37,12 @@
 #'
 #' @details Users should provide the appropriate columns in \code{measuredData}, depending on the type of output to be evaluated:
 #' \itemize{
-#'   \item{\code{"SWC" or "REW"}: A column named \code{"SWC"} should be present, containing soil moisture content in percent volume. When \code{type="REW"}, observed values are divided by the 90\% quantile, which is assumed to be the moisture content at field capacity.}
+#'   \item{\code{"SWC", "RWC", "REW"}: A column with the same name should be present. By default, the first soil layer is compared. Evaluation can be done for specific soil layers, for example using "RWC.2" for the relative water content of the second layer.}
 #'   \item{\code{"ETR"} or \code{"SE+TR"}: A column named \code{"ETR"} should be present, containing stand's evapotranspiration in mm/day (or mm/week, mm/month, etc, depending on the temporal resolution). If \code{type="ETR"} observed values will be compared against modelled evapotranspiration (i.e. sum of transpiration, soil evaporation and interception loss), whereas if \code{type= "SE+TR"} observed values will be compared against the sum of transpiration and soil evaporation only.}
+#'   \item{\code{"LE"}: A column named \code{"LE"} should be present containing daily latent heat turbulent flux in MJ/m2.}
+#'   \item{\code{"H"}: A column named \code{"H"} should be present containing daily sensible heat turbulent flux in MJ/m2.}
 #'   \item{\code{"E"}: For each plant cohort whose transpiration is to be evaluated, a column starting with \code{"E_"} and continuing with a cohort name (e.g. \code{"E_T1_68"}) with transpiration in L/m2/day on a leaf area basis (or L/m2/week, L/m2/month, etc, depending on the temporal resolution).}
+#'   \item{\code{"GPP"}: A column named \code{"GPP"} should be present containing daily gross primary productivity in gC/m2.}
 #'   \item{\code{"LFMC"}: For each plant cohort whose transpiration is to be evaluated, a column starting with \code{"FCM_"} and continuing with a cohort name (e.g. \code{"FMC_T1_68"}) with fuel moisture content as percent of dry weight.}
 #'   \item{\code{"WP"}: For each plant cohort whose transpiration is to be evaluated, two columns, one starting with \code{"PD_"} (for pre-dawn) and the other with \code{"MD_"} (for midday), and continuing with a cohort name (e.g. \code{"PD_T1_68"}). They should contain leaf water potential values in MPa. These are compared against sunlit water potentials.}
 #'   \item{\code{"BAI"}: For each plant cohort whose growth is to be evaluated, a column starting with \code{"BAI_"} and continuing with a cohort name (e.g. \code{"BAI_T1_68"}) with basal area increment in cm2/day, cm2/week, cm2/month or cm2/year, depending on the temporal resolution.}
@@ -35,7 +52,8 @@
 #' }
 #' Additional columns may exist with the standard error of measured quantities. These should be named as the referred quantity, followed by \code{"_err"} (e.g. \code{"PD_T1_68_err"}), and are used to draw confidence intervals around observations.
 #'  
-#' Row names in \code{measuredData} indicate the date of measurement (in the case of days). If measurements refer to months or years, row names should also be in a "year-month-day" format, although with "01" for days and/or months (e.g. "2001-02-01" for february 2001, or "2001-01-01" for year 2001).
+#' Row names in \code{measuredData} indicate the date of measurement (in the case of days). Alternatively, a column called \code{"dates"} can contain the measurement dates.
+#' If measurements refer to months or years, row names should also be in a "year-month-day" format, although with "01" for days and/or months (e.g. "2001-02-01" for february 2001, or "2001-01-01" for year 2001).
 #'
 #' @return 
 #' \itemize{
@@ -66,22 +84,22 @@
 #' data(examplemeteo)
 #' 
 #' #Load example plot plant data
-#' data(exampleforestMED)
+#' data(exampleforest)
 #' 
 #' #Default species parameterization
 #' data(SpParamsMED)
 #' 
-#' #Initialize soil with default soil params (4 layers)
-#' examplesoil = soil(defaultSoilParams(4))
+#' #Define soil with default soil params (4 layers)
+#' examplesoil <- defaultSoilParams(4)
 #' 
 #' #Initialize control parameters
-#' control = defaultControl("Granier")
+#' control <- defaultControl("Granier")
 #' 
 #' #Initialize input
-#' x1 = forest2spwbInput(exampleforestMED,examplesoil, SpParamsMED, control)
+#' x1 <- spwbInput(exampleforest, examplesoil, SpParamsMED, control)
 #' 
 #' #Call simulation function
-#' S1<-spwb(x1, examplemeteo, latitude = 41.82592, elevation = 100)
+#' S1 <- spwb(x1, examplemeteo, latitude = 41.82592, elevation = 100)
 #' 
 #' #Load observed data (in this case the same simulation results with some added error)  
 #' data(exampleobs)
@@ -102,42 +120,43 @@
 evaluation_table<-function(out, measuredData, type = "SWC", cohort = NULL, 
                            temporalResolution = "day") {
   
+  # allow dates in column 'dates'
+  if("dates" %in% names(measuredData)) {
+    row.names(measuredData) <- as.character(measuredData$dates)
+  }
   # Check arguments
   temporalResolution = match.arg(temporalResolution, c("day", "week", "month", "year"))
+  soil_layers_opts <- c("", ".1", ".2", ".3", ".4", ".5", ".6", ".7", ".8", ".9", ".10")
+  soil_opts <- c(paste0("SWC", soil_layers_opts),
+                 paste0("RWC", soil_layers_opts),
+                 paste0("REW", soil_layers_opts))
   if("spwbInput" %in% names(out)) {
     modelInput<-out[["spwbInput"]]
-    type = match.arg(type, c("SWC", "REW","E", "ETR", "SE+TR", "WP", "LFMC"))
+    type = match.arg(type, c(soil_opts,"E", "ETR", "SE+TR", "LE", "H", "WP", "LFMC", "GPP"))
   } else {
     modelInput<- out[["growthInput"]]
-    type = match.arg(type, c("SWC", "REW","E", "ETR", "SE+TR", "WP", "LFMC", 
+    type = match.arg(type, c(soil_opts,"E", "ETR", "SE+TR", "LE", "H", "WP", "LFMC", "GPP", 
                              "BAI", "DI","DBH", "Height"))
   }
-  if(type=="SWC") {
-    sm = out$Soil
+  if(substr(type,1,3) %in% c("REW", "SWC", "RWC")) {
+    sm = as.data.frame(out$Soil[[substr(type,1,3)]])
     d = rownames(sm)
-    fc = soil_thetaFC(modelInput$soil, model = modelInput$control$soilFunctions)
-    mod = sm$W.1*fc[1]
-    df <- data.frame(Dates = as.Date(d), Observed = NA, Modelled = mod)
-    
-    if(!("SWC" %in% names(measuredData))) stop(paste0("Column 'SWC' not found in measured data frame."))
-    seld = rownames(measuredData) %in% d
-    df$Observed[d %in% rownames(measuredData)] = measuredData$SWC[seld]
-    
-    if("SWC_err" %in% names(measuredData))  {
-      df$obs_lower[d %in% rownames(measuredData)] = df$Observed[d %in% rownames(measuredData)] - 1.96*measuredData[["SWC_err"]][seld]
-      df$obs_upper[d %in% rownames(measuredData)] = df$Observed[d %in% rownames(measuredData)] + 1.96*measuredData[["SWC_err"]][seld]
+    if(type=="SWC")  var_mod <- "1"
+    else if(type=="REW")  var_mod <- "1"
+    else if(type=="RWC")  var_mod <- "1"
+    else {
+      var_mod  <- substr(type,5, nchar(type))
     }
-  } 
-  else if(type=="REW") {
-    sm = out$Soil
-    d = rownames(sm)
-    df <- data.frame(Dates = as.Date(d), Observed = NA, Modelled = sm$W.1)
+    df <- data.frame(Dates = as.Date(d), Observed = NA, Modelled = sm[[var_mod]])
     
-    if(!("SWC" %in% names(measuredData))) stop(paste0("Column 'SWC' not found in measured data frame."))
+    if(!(type %in% names(measuredData))) stop(paste0("Column '", type, "' not found in measured data frame."))
     seld = rownames(measuredData) %in% d
-    q_obs = quantile(measuredData$SWC[seld], p=c(0.90), na.rm=T) # To avoid peaks over field capacity
-    df$Observed[d %in% rownames(measuredData)] = measuredData$SWC[seld]/q_obs[1]
-    
+    df$Observed[d %in% rownames(measuredData)] = measuredData[seld, type]
+    errcolumn = paste0(type, "_err")
+    if(errcolumn %in% names(measuredData))  {
+      df$obs_lower[d %in% rownames(measuredData)] = df$Observed[d %in% rownames(measuredData)] - 1.96*measuredData[[errcolumn]][seld]
+      df$obs_upper[d %in% rownames(measuredData)] = df$Observed[d %in% rownames(measuredData)] + 1.96*measuredData[[errcolumn]][seld]
+    }
   } 
   else if(type=="E") {
     pt = out$Plants$Transpiration
@@ -167,6 +186,20 @@ evaluation_table<-function(out, measuredData, type = "SWC", cohort = NULL,
     if(!("ETR" %in% names(measuredData))) stop(paste0("Column 'ETR' not found in measured data frame."))
     df$Observed[d %in% rownames(measuredData)] = measuredData$ETR[rownames(measuredData) %in% d]
   }
+  else if(type=="LE") {
+    LEmod = out$EnergyBalance$LEVcan + out$EnergyBalance$LEVsoil
+    d = rownames(out$EnergyBalance)
+    df = data.frame(Dates = as.Date(d), Observed = NA, Modelled = LEmod)
+    if(!("LE" %in% names(measuredData))) stop(paste0("Column 'LE' not found in measured data frame."))
+    df$Observed[d %in% rownames(measuredData)] = measuredData$LE[rownames(measuredData) %in% d]
+  }
+  else if(type=="H") {
+    Hmod = out$EnergyBalance$Hcan
+    d = rownames(out$EnergyBalance)
+    df = data.frame(Dates = as.Date(d), Observed = NA, Modelled = Hmod)
+    if(!("H" %in% names(measuredData))) stop(paste0("Column 'H' not found in measured data frame."))
+    df$Observed[d %in% rownames(measuredData)] = measuredData$H[rownames(measuredData) %in% d]
+  }
   else if(type=="SE+TR") {
     ET1 = out$WaterBalance$SoilEvaporation+out$WaterBalance$Transpiration
     d = rownames(out$WaterBalance)
@@ -230,6 +263,14 @@ evaluation_table<-function(out, measuredData, type = "SWC", cohort = NULL,
     if(!(obscolumn %in% names(measuredData))) stop(paste0("Column '", obscolumn, "' not found in measured data frame."))
     df$Observed[d %in% rownames(measuredData)] = measuredData[[obscolumn]][rownames(measuredData) %in% d] 
   }
+  else if(type=="GPP") {
+    GPP = rowSums(out$Plants$GrossPhotosynthesis)
+    d = rownames(out$Plants$GrossPhotosynthesis)
+    df = data.frame(Dates = as.Date(d), Observed = NA, Modelled = GPP)
+    
+    if(!("GPP" %in% names(measuredData))) stop(paste0("Column 'GPP' not found in measured data frame."))
+    df$Observed[d %in% rownames(measuredData)] = measuredData$GPP[rownames(measuredData) %in% d]
+  }
   else if(type=="BAI") {
     SAg = out$GrowthMortality$SAgrowth
     d = rownames(SAg)
@@ -351,34 +392,16 @@ evaluation_stats<-function(out, measuredData, type="SWC", cohort = NULL,
     return(c(n = sum(sel_complete), Bias= Bias, Bias.rel= Bias.rel,MAE = MAE, MAE.rel = MAE.rel, r = r, NSE = NSE, NSE.abs = NSE.abs))
   }
   
-  # Check arguments
-  if("spwbInput" %in% names(out)) {
-    modelInput<-out[["spwbInput"]]
-    type = match.arg(type, c("SWC", "REW","E", "ETR","SE+TR", "WP", "FMC"))
-  } else {
-    modelInput<- out[["growthInput"]]
-    type = match.arg(type, c("SWC", "REW","E", "ETR","SE+TR", "WP", "FMC", 
-                             "BAI", "DI","DBH", "Height"))
-  }
-  
   df = evaluation_table(out = out, measuredData = measuredData, 
                         type = type, cohort = cohort, 
                         temporalResolution = temporalResolution)
-  if(type=="SWC") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="REW") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="E") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="FMC") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="ETR") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="SE+TR") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="WP") {
+  if(type=="WP") {
     eval_res = as.data.frame(rbind(evalstats(df$PD_obs, df$PD_mod),
                                    evalstats(df$MD_obs, df$MD_mod)))
     row.names(eval_res)<-c("Predawn potentials", "Midday potentials")
+  } else {
+    eval_res = evalstats(df$Observed, df$Modelled)
   }
-  else if(type=="BAI") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="DI") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="DBH") eval_res = evalstats(df$Observed, df$Modelled)
-  else if(type=="Height") eval_res = evalstats(df$Observed, df$Modelled)
   return(eval_res)
 }
 
@@ -389,8 +412,12 @@ evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL,
   scatterplot<-function(df, xlab="", ylab="", title=NULL, err = FALSE) {
     g<-ggplot(df, aes(x=.data$Modelled))
     if(err) {
-      g<-g+
-        geom_pointrange(aes(y = .data$Observed, ymin = .data$obs_lower, ymax = .data$obs_upper),cex=0.5)
+      data_err <- df[!is.na(df$obs_lower) & !is.na(df$obs_upper), , drop = FALSE]
+      if(nrow(data_err)>0) {
+        g<-g+
+          geom_pointrange(aes(y = .data$Observed, ymin = .data$obs_lower, ymax = .data$obs_upper),cex=0.5,
+                          data = data_err)
+      }
     }
     g<-g + 
       geom_point(aes(y = .data$Observed), cex=0.5)+
@@ -427,33 +454,40 @@ evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL,
   plotType = match.arg(plotType, c("dynamics", "scatter"))
   if("spwbInput" %in% names(out)) {
     modelInput<-out[["spwbInput"]]
-    type = match.arg(type, c("SWC", "REW","E", "ETR","SE+TR", "WP", "FMC"))
   } else {
     modelInput<- out[["growthInput"]]
-    type = match.arg(type, c("SWC", "REW","E", "ETR","SE+TR", "WP", "FMC", 
-                             "BAI","DI", "DBH", "Height"))
   }
-  
   df = evaluation_table(out = out, measuredData = measuredData, 
                         type = type, cohort = cohort, 
                         temporalResolution = temporalResolution)
   
-  if(type=="SWC") {
+  if(type %in% paste0("SWC", c("", paste0(".", 1:10)))) {
     if(plotType=="dynamics") {
       g<-dynamicsplot(df, ylab = expression(paste("Soil moisture ",(m^{3}%.%m^{-3}))),
-                      err = ("SWC_err" %in% names(measuredData)))
+                      err = (paste0(type,"_err") %in% names(measuredData)))
     } else {
       g<-scatterplot(df, xlab  = expression(paste("Measured soil moisture ",(m^{3}%.%m^{-3}))),
                      ylab = expression(paste("Measured soil moisture ",(m^{3}%.%m^{-3}))), 
-                     err = ("SWC_err" %in% names(measuredData)))
+                     err = (paste0(type,"_err") %in% names(measuredData)))
     }
   } 
-  else if(type=="REW") {
+  else if(type %in% paste0("RWC", c("", paste0(".", 1:10)))) {
+    if(plotType=="dynamics") {
+      g<-dynamicsplot(df, ylab = "Relative water content (RWC)")
+    } else {
+      g<-scatterplot(df, xlab  = "Modelled relative water content (RWC)",
+                     ylab = "Measured relative water content (RWC)", 
+                     err = (paste0(type,"_err") %in% names(measuredData)))
+      
+    }
+  }
+  else if(type %in% paste0("REW", c("", paste0(".", 1:10)))) {
     if(plotType=="dynamics") {
       g<-dynamicsplot(df, ylab = "Relative extractable soil water (REW)")
     } else {
       g<-scatterplot(df, xlab  = "Modelled relative extractable soil water (REW)",
-                     ylab = "Measured relative extractable soil water (REW)")
+                     ylab = "Measured relative extractable soil water (REW)", 
+                     err = (paste0(type,"_err") %in% names(measuredData)))
       
     }
   }
@@ -597,6 +631,22 @@ evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL,
                          ylab ="Measured ETR (mm)")
     }
   }
+  else if(type=="LE") {
+    if(plotType=="dynamics") {
+      g<-dynamicsplot(df, ylab = "Latent heat (MJ/m2)")
+    } else {
+      g<-scatterplot(df, xlab  = "Modelled latent heat (MJ/m2)",
+                     ylab ="Measured latent heat (MJ/m2)")
+    }
+  }
+  else if(type=="H") {
+    if(plotType=="dynamics") {
+      g<-dynamicsplot(df, ylab = "Canpy sensible heat (MJ/m2)")
+    } else {
+      g<-scatterplot(df, xlab  = "Modelled sensible heat (MJ/m2)",
+                     ylab ="Measured sensible heat (MJ/m2)")
+    }
+  }
   else if(type=="SE+TR") {
     if(plotType=="dynamics") {
       g<-dynamicsplot(df, ylab = "ETR or SE+TR (mm)", str_obs = "Observed (ETR)", str_mod = "Modelled (SE+TR)")
@@ -605,6 +655,14 @@ evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL,
                      ylab ="Measured ETR (mm)")
     }
   }
+  else if(type=="GPP") {
+    if(plotType=="dynamics") {
+      g<-dynamicsplot(df, ylab = "GPP (gC/m2)")
+    } else {
+      g<-scatterplot(df, xlab  = "Modelled GPP (gC/m2)",
+                     ylab ="Measured GPP (gC/m2)")
+    }
+  }
   else if(type=="WP"){
     wtMD = out$Plants$LeafPsiMin
     wtPD = out$Plants$LeafPsiMax
@@ -672,4 +730,4 @@ evaluation_metric<-function(out, measuredData, type="SWC", cohort=NULL,
          "NSE.abs" = 1 - (sum(abs(obs-pred))/sum(abs(obs-mean(obs))))
   )
   return(m)
-}
\ No newline at end of file
+}
