@@ -22,7 +22,8 @@ hydraulics_vulnerabilityCurvePlot<-function(x, soil = NULL, type="leaf",  vulner
   TYPES_FUN <- c("Weibull", "Sigmoid")
   vulnerabilityFunction <- match.arg(vulnerabilityFunction,TYPES_FUN)  
   
-  if(!(x$control$transpirationMode %in% c("Sperry", "Cochard"))) stop("x has to be initialized using 'Sperry' or 'Cochard' transpiration modes")
+  if(!(x$control$transpirationMode %in% c("Sperry", "Sureau"))) stop("x has to be initialized using 'Sperry' or 'Sureau' transpiration modes")
+
   
   cohortnames <- row.names(x$cohorts)
   spnames <- x$cohorts$Name
@@ -171,6 +172,13 @@ hydraulics_vulnerabilityCurvePlot<-function(x, soil = NULL, type="leaf",  vulner
   } 
   else if(type=="rhizosphere") {
     if(is.null(soil)) stop("Please supply a non-null soil object!")
+    if(!inherits(soil, "soil")) {
+      if(inherits(soil, "data.frame")){
+        soil <- soil(soil)
+      } else {
+        stop("soil has to be of class 'data.frame' or 'soil'")
+      }
+    } 
     if(is.null(ylab)) {
       if(!relative) ylab <- expression(paste("Rhizosphere conductance  ", (mmol%.%s^{-1}%.%m^{-2}%.%MPa^{-1})))
       else ylab <- "Rhizosphere conductance (% of maximum)"
