@@ -134,6 +134,7 @@ void updatePhenology(List x, int doy, double photoperiod, double tmean) {
             leafSenescence[j] = leafSenescenceStatus(Ssen[j],sen[j]);
             leafDormancy[j] = leafSenescence[j];
           }
+          if(leafDormancy[j]) phi[j] = 0.0;
           budFormation[j] = !leafDormancy[j]; //Buds can be formed (i.e target leaf area) until dormancy occurs
         }
         // Rcout << doy<< " "<< photoperiod<<" "<< rsen <<" "<< sen[j]<<" "<<  leafSenescence[j] << "\n";
@@ -186,7 +187,9 @@ void updatePhenology(List x, int doy, double photoperiod, double tmean) {
       budFormation[j] = true;
       leafDormancy[j] = false;
     }
+    // Rcout<< j << " phi "<< phi[j] <<" ";
   }
+  // Rcout<<"\n";
 }
 
 //' @param wind Average day wind speed (in m/s).
@@ -198,7 +201,7 @@ void updateLeaves(List x, double wind, bool fromGrowthModel) {
   DataFrame above = Rcpp::as<Rcpp::DataFrame>(x["above"]);
   NumericVector LAI_live = above["LAI_live"];
   NumericVector LAI_dead = above["LAI_dead"];
-  NumericVector LAI_expanded = above["LAI_expanded"];
+  NumericVector LAI = above["LAI_expanded"];
   int numCohorts = LAI_live.size();
 
   DataFrame paramsPhenology = Rcpp::as<Rcpp::DataFrame>(x["paramsPhenology"]);
@@ -211,7 +214,7 @@ void updateLeaves(List x, double wind, bool fromGrowthModel) {
   LogicalVector leafUnfolding = internalPhenology["leafUnfolding"];
   LogicalVector leafSenescence = internalPhenology["leafSenescence"];
   LogicalVector leafDormancy = internalPhenology["leafDormancy"];
-  
+
   for(int j=0;j<numCohorts;j++) {
     bool leafFall = true;
     if(phenoType[j] == "winter-semideciduous") leafFall = leafUnfolding[j];
@@ -219,14 +222,14 @@ void updateLeaves(List x, double wind, bool fromGrowthModel) {
     //Leaf unfolding and senescence only dealt with if called from spwb
     if(!fromGrowthModel) {
       if(phenoType[j] == "winter-deciduous" || phenoType[j] == "winter-semideciduous") {
-        if((leafSenescence[j]) && (LAI_expanded[j]>0.0)) {
-          double LAI_exp_prev= LAI_expanded[j]; //Store previous value
-          LAI_expanded[j] = 0.0; //Update expanded leaf area (will decrease if LAI_live decreases)
+        if((leafSenescence[j]) && (LAI[j]>0.0)) {
+          double LAI_exp_prev= LAI[j]; //Store previous value
+          LAI[j] = 0.0; //Update expanded leaf area (will decrease if LAI_live decreases)
           LAI_dead[j] += LAI_exp_prev;//Check increase dead leaf area if expanded leaf area has decreased
           leafSenescence[j] = false;
         } 
         else if(leafUnfolding[j]) {
-          LAI_expanded[j] = LAI_live[j]*phi[j]; //Update expanded leaf area (will decrease if LAI_live decreases)
+          LAI[j] = LAI_live[j]*phi[j]; //Update expanded leaf area (will decrease if LAI_live decreases)
         }
       } 
     }
