@@ -5,8 +5,21 @@
 #endif
 using namespace Rcpp;
 
+double gLeafBoundary(double u, double leafWidth, double gBound0 = 0.397);
+double gCrown(double u, double gCrown0 = 0.150);
+
 NumericVector leafphotosynthesis(double Q, double Catm, double Gc, double Tleaf, double Vmax298, double Jmax298, bool verbose=false);
 
+NumericVector photosynthesisBaldocchi(double Q, 
+                                      double Catm, 
+                                      double Tleaf, 
+                                      double u,
+                                      double Vmax298, 
+                                      double Jmax298, 
+                                      double leafWidth,
+                                      double Gsw_AC_slope,
+                                      double Gsw_AC_intercept);
+
 double VmaxTemp(double Vmax298, double Tleaf);
 double JmaxTemp(double Jmax298, double Tleaf);
 
